Files — Breezy 3.0.2dev documentation

Table of Contents (3.0.2dev)

# Files

On Unix

  ~/.config/breezy/breezy.conf

On Windows

  C:\Documents and Settings\username\Application Data\Breezy\2.0\breezy.conf

Contains the user’s default configuration. The section `[DEFAULT]` is used to define general configuration that will be applied everywhere. The section `[ALIASES]` can be used to create command aliases for commonly used options.

A typical config file might look something like:

    [DEFAULT]
    email=John Doe <jdoe@isp.com>

    [ALIASES]
    commit = commit --strict
    log10 = log --short -r -10..-1